==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/TCPSettingsFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import me.snowdrop.istio.api.DurationFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import me.snowdrop.istio.api.Duration;
import com.fasterxml.jackson.databind.JsonSerializer;
import java.lang.String;
import com.fasterxml.jackson.databind.JsonDeserializer;
import java.lang.Integer;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Long;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.SerializerProvider;
import java.lang.Boolean;
import java.lang.Override;
import com.fasterxml.jackson.core.JsonParser;
import me.snowdrop.istio.api.DurationBuilder;

public interface TCPSettingsFluent<A extends TCPSettingsFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildConnectTimeout instead.
 * @return The buildable object.
 */
@Deprecated public Duration getConnectTimeout();
    public Duration buildConnectTimeout();
    public A withConnectTimeout(Duration connectTimeout);
    public Boolean hasConnectTimeout();
    public A withNewConnectTimeout(Integer nanos,Long seconds);
    public TCPSettingsFluent.ConnectTimeoutNested<A> withNewConnectTimeout();
    public TCPSettingsFluent.ConnectTimeoutNested<A> withNewConnectTimeoutLike(Duration item);
    public TCPSettingsFluent.ConnectTimeoutNested<A> editConnectTimeout();
    public TCPSettingsFluent.ConnectTimeoutNested<A> editOrNewConnectTimeout();
    public TCPSettingsFluent.ConnectTimeoutNested<A> editOrNewConnectTimeoutLike(Duration item);
    public Integer getMaxConnections();
    public A withMaxConnections(Integer maxConnections);
    public Boolean hasMaxConnections();
    public A withNewMaxConnections(String arg1);
    public A withNewMaxConnections(int arg1);

    public interface ConnectTimeoutNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DurationFluent<TCPSettingsFluent.ConnectTimeoutNested<N>>{

        
    public N and();    public N endConnectTimeout();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/TCPSettingsFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.databind.JsonDeserializer;
import java.lang.Deprecated;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.SerializerProvider;
import java.lang.Boolean;
import java.lang.Override;
import com.fasterxml.jackson.core.JsonParser;
import me.snowdrop.istio.api.DurationFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import me.snowdrop.istio.api.Duration;
import java.lang.Integer;
import java.lang.Long;
import me.snowdrop.istio.api.DurationBuilder;

public interface TCPSettingsFluent<A extends TCPSettingsFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildConnectTimeout instead.
 * @return The buildable object.
 */
@Deprecated public Duration getConnectTimeout();
    public Duration buildConnectTimeout();
    public A withConnectTimeout(Duration connectTimeout);
    public Boolean hasConnectTimeout();
    public A withNewConnectTimeout(Integer nanos,Long seconds);
    public TCPSettingsFluent.ConnectTimeoutNested<A> withNewConnectTimeout();
    public TCPSettingsFluent.ConnectTimeoutNested<A> withNewConnectTimeoutLike(Duration item);
    public TCPSettingsFluent.ConnectTimeoutNested<A> editConnectTimeout();
    public TCPSettingsFluent.ConnectTimeoutNested<A> editOrNewConnectTimeout();
    public TCPSettingsFluent.ConnectTimeoutNested<A> editOrNewConnectTimeoutLike(Duration item);
    public Integer getMaxConnections();
    public A withMaxConnections(Integer maxConnections);
    public Boolean hasMaxConnections();
    
/**
 * This method has been deprecated, please use method buildTcpKeepalive instead.
 * @return The buildable object.
 */
@Deprecated public TcpKeepalive getTcpKeepalive();
    public TcpKeepalive buildTcpKeepalive();
    public A withTcpKeepalive(TcpKeepalive tcpKeepalive);
    public Boolean hasTcpKeepalive();
    public TCPSettingsFluent.TcpKeepaliveNested<A> withNewTcpKeepalive();
    public TCPSettingsFluent.TcpKeepaliveNested<A> withNewTcpKeepaliveLike(TcpKeepalive item);
    public TCPSettingsFluent.TcpKeepaliveNested<A> editTcpKeepalive();
    public TCPSettingsFluent.TcpKeepaliveNested<A> editOrNewTcpKeepalive();
    public TCPSettingsFluent.TcpKeepaliveNested<A> editOrNewTcpKeepaliveLike(TcpKeepalive item);

    public interface ConnectTimeoutNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DurationFluent<TCPSettingsFluent.ConnectTimeoutNested<N>>{

        
    public N and();    public N endConnectTimeout();
}
    public interface TcpKeepaliveNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TcpKeepaliveFluent<TCPSettingsFluent.TcpKeepaliveNested<N>>{

        
    public N and();    public N endTcpKeepalive();
}


}
